package com.ai.ipu.example.db;

import com.ai.ipu.sql.parse.statement.Select;
import com.ai.ipu.sql.parse.statement.Update;
import com.ai.ipu.sql.parse.util.SqlParser;
import org.junit.Test;

import java.util.*;

/**
 * @author liutong3
 * @team IPU
 * @date 2019/10/18 11:10
 */
public class IpuSqlParseExample {
    /**
     * 通过sql语句解析sql
     */
    @Test
    public void testParse() {
        SqlParser sqlParser = new SqlParser("select string_type, int_type from ipu_db_demo where pk = '1'");
        System.out.println("sql语句类型：" + sqlParser.getType());
        System.out.println("查询的表是：" + sqlParser.getTableName());
        System.out.println("查询条件是：" + sqlParser.getWhere());
    }

    /**
     * 通过sql语句以及数据库连接解析sql
     */
    @Test
    public void testParseWithConnName() {
        SqlParser sqlParser = new SqlParser("db_druid", "select string_type, int_type from ipu_db_demo where pk = '1'");
        System.out.println("sql语句类型：" + sqlParser.getType());
        System.out.println("查询的表是：" + sqlParser.getTableName());
        System.out.println("查询条件是：" + sqlParser.getWhere());
        //与数据库不符合的表
        try {
            sqlParser = new SqlParser("test", "select string_type, int_type from a where pk = '1'");
            System.out.println("sql语句类型：" + sqlParser.getType());
            System.out.println("查询的表是：" + sqlParser.getTableName());
            System.out.println("查询条件是：" + sqlParser.getWhere());
        } catch (Exception e) {
            System.out.println(e);
        }
    }

    /**
     * 快速构建sql语句
     */
    @Test
    public void testCreateSql() {
        //拼接sql语句：根据实体IpuDbDemoDto以及pk更新ipu_db_demo的所有字段
        int pk = 1;
        Map<String, Object> input = new HashMap<String, Object>();
        input.put("string_type", "测试");
        input.put("int_type", 1);
        input.put("decimal_type", 1);
        input.put("date_type", new Date());
        input.put("datetime_type", new Date());
        input.put("null_type", "");
        //通过stringbuilder拼接sql
        StringBuilder stringBuilder = new StringBuilder("update ipu_db_demo set");
        boolean frist = true;
        for (Map.Entry<String, Object> entry : input.entrySet()) {
            if (frist) {
                stringBuilder.append(" " + entry.getKey() + " = '" + entry.getValue() + "'");
                frist = false;
            } else {
                stringBuilder.append(", " + entry.getKey() + " = '" + entry.getValue() + "'");
            }
        }
        stringBuilder.append(" where pk = " + pk);
        System.out.println(stringBuilder.toString());
        //通过ipu-sql-parse拼接sql
        Update update = new Update("ipu_db_demo");
        for (Map.Entry<String, Object> entry : input.entrySet()) {
            update.addColumn(entry.getKey(), "'" + entry.getValue() + "'");
        }
        update.where("pk = " + pk);
        System.out.println(update.getSql());
    }

    /**
     * 快速更新sql语句
     */
    @Test
    public void testChangeSql() {
        //为原sql变更查询列和查询条件
        String oldSql = "select string_type, int_type from ipu_db_demo where pk = '1'";
        List<String> selectParams = new ArrayList<String>();
        selectParams.add("string_type");
        selectParams.add("int_type");
        selectParams.add("decimal_type");
        selectParams.add("date_type");
        selectParams.add("datetime_type");
        selectParams.add("null_type");
        String where = "pk <> '1'";
        //通过string更新sql
        String[] list = oldSql.split("where");
        String newSql = list[0] + " where " + where;
        list = newSql.split("from");
        String param = "";
        for (String obj : selectParams) {
            if ("".equals(param)) {
                param += obj;
            } else {
                param += ", " + obj;
            }

        }
        newSql = "select " + param + list[1];
        System.out.println(newSql);
        //通过ipu-sql-parse变更sql
        SqlParser sqlParser = new SqlParser(oldSql);
        Select select = (Select) sqlParser.getStatement();
        select.changeAllColumns(selectParams.toArray(new String[selectParams.size()]));
        select.removeAllWhere();
        select.where(where);
        System.out.println(select.getSql());
    }
}
