package com.ai.ipu.example.db.dao;

import com.ai.ipu.database.dao.impl.AbstractBizDao;
import com.ai.ipu.example.db.model.IpuDbDemoDto;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.*;

/**
 * @author liutong3
 * @team IPU
 * @date 2019/10/15 16:10
 * @desc dao层，根据sql调用ipu-database的execute方法连接数据库
 */
public class IpuDbDemoDao extends AbstractBizDao {
    public IpuDbDemoDao(String connName) throws IOException {
        super(connName);
    }

    public List<IpuDbDemoDto> select() throws Exception {
        String sql = "select pk, string_type, int_type, decimal_type, date_type, datetime_type, null_type from ipu_db_demo";
        List<Map<String, Object>> result = dao.executeSelect(sql);
        List<IpuDbDemoDto> list = new ArrayList<IpuDbDemoDto>();
        for (Map<String, Object> obj : result) {
            IpuDbDemoDto ipuDbDemoDto = new IpuDbDemoDto();
            ipuDbDemoDto.setPk((Integer) obj.get("pk"));
            ipuDbDemoDto.setString_type((String) obj.get("string_type"));
            ipuDbDemoDto.setInt_type((Integer) obj.get("int_type"));
            ipuDbDemoDto.setDecimal_type((BigDecimal) obj.get("decimal_type"));
            ipuDbDemoDto.setDate_type((Date) obj.get("date_type"));
            ipuDbDemoDto.setDatetime_type((Date) obj.get("datetime_type"));
            ipuDbDemoDto.setNull_type((String) obj.get("null_type"));
            list.add(ipuDbDemoDto);
        }
        return list;
    }

    public IpuDbDemoDto selectById(int id) throws Exception {
        String sql = "select pk, string_type, int_type, decimal_type, date_type, datetime_type, null_type from ipu_db_demo where pk=#{pk}";
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("pk" ,id);
        List<Map<String, Object>> result = dao.executeSelect(sql, param);
        if (result == null || result.size() != 1) {
            return null;
        } else {
            Map<String, Object> obj = result.get(0);
            IpuDbDemoDto ipuDbDemoDto = new IpuDbDemoDto();
            ipuDbDemoDto.setPk((Integer) obj.get("pk"));
            ipuDbDemoDto.setString_type((String) obj.get("string_type"));
            ipuDbDemoDto.setInt_type((Integer) obj.get("int_type"));
            ipuDbDemoDto.setDecimal_type((BigDecimal) obj.get("decimal_type"));
            ipuDbDemoDto.setDate_type((Date) obj.get("date_type"));
            ipuDbDemoDto.setDatetime_type((Date) obj.get("datetime_type"));
            ipuDbDemoDto.setNull_type((String) obj.get("null_type"));
            return ipuDbDemoDto;
        }
    }

    public int insert(IpuDbDemoDto ipuDbDemoDto) throws Exception {
        String sql = "insert into ipu_db_demo(pk, string_type, int_type, decimal_type, date_type, datetime_type, null_type) values (#{pk}, #{string_type}, #{int_type}, #{decimal_type}, #{date_type}, #{datetime_type}, #{null_type})";
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("pk", ipuDbDemoDto.getPk());
        param.put("string_type", ipuDbDemoDto.getPk());
        param.put("int_type", ipuDbDemoDto.getInt_type());
        param.put("decimal_type", ipuDbDemoDto.getDecimal_type());
        param.put("date_type", ipuDbDemoDto.getDate_type());
        param.put("datetime_type", ipuDbDemoDto.getDatetime_type());
        param.put("null_type", ipuDbDemoDto.getNull_type());
        return dao.executeInsert(sql, param);
    }

    public int deleteById(int id) throws Exception {
        String sql = "delete from ipu_db_demo where pk = #{pk}";
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("pk", id);
        return dao.executeDelete(sql, param);
    }

    public int updateString_typeById(int id, String value) throws Exception {
        String sql = "update ipu_db_demo set string_type = #{string_type} where pk = #{pk}";
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("pk", id);
        param.put("string_type", value);
        return dao.executeDelete(sql, param);
    }
}
