package com.ai.ipu.example.hadoop;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.BlockLocation;
import org.apache.hadoop.fs.FSDataOutputStream;
import org.apache.hadoop.fs.FileStatus;
import org.apache.hadoop.fs.FileSystem;
import org.apache.hadoop.fs.Path;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import java.net.URI;

/**
 * 类描述
 *
 * @author lilb3@asiainfo.com
 * @since 2019-07-01 15:36
 **/
public class HadoopExample {
    private FileSystem hdfs = null;
    private static final String HDFS_SPLIT_STRING = "/";


    @Before
    public void setBefore() throws Exception {
        Configuration configuration = new Configuration();
        configuration.set("dfs.client.use.datanode.hostname", HadoopConfig.getDfsClientUseDatanodeHostname());
        String hdfsPath = HadoopConfig.getHdfsPath();
        hdfs = FileSystem.get(new URI(hdfsPath), configuration);
    }

    @After
    public void setAfter() throws Exception {
        if (hdfs != null) {
            hdfs.close();
        }
    }

    @Test
    public void mkdir() throws Exception {
        String newDir = HDFS_SPLIT_STRING + HadoopConfig.getDirName();
        boolean result = hdfs.mkdirs(new Path(newDir));
        if (result) {
            System.out.println("Success!");
        } else {
            System.out.println("Failed!");
        }
    }

    @Test
    public void createFile() throws Exception {
        String filePath = HDFS_SPLIT_STRING + HadoopConfig.getDirName() + HDFS_SPLIT_STRING + HadoopConfig.getFileName();
        FSDataOutputStream create = hdfs.create(new Path(filePath));
        create.writeBytes(HadoopConfig.getWriteString());
        create.close();
        System.out.println("Finish!");
    }

    @Test
    public void copyFromLocalFile() throws Exception {
        String localFile = HadoopConfig.getUploadLocalFile();
        String toHDFS = HDFS_SPLIT_STRING + HadoopConfig.getDirName() + HDFS_SPLIT_STRING;
        hdfs.copyFromLocalFile(new Path(localFile), new Path(toHDFS));
        System.out.println("Finish!");
    }

    @Test
    public void copyToLocalFile() throws Exception {
        String hdfsFile = HDFS_SPLIT_STRING + HadoopConfig.getDirName() + HDFS_SPLIT_STRING + HadoopConfig.getFileName();
        String localFile = HadoopConfig.getDownloadLocalFile();
        hdfs.copyToLocalFile(false, new Path(hdfsFile), new Path(localFile));
        System.out.println("Finish!");
    }

    @Test
    public void listFile() throws Exception {
        iteratorListFile(hdfs, new Path(HDFS_SPLIT_STRING));
    }

    @Test
    public void locateFile() throws Exception {
        Path file = new Path(HDFS_SPLIT_STRING + HadoopConfig.getDirName() + HDFS_SPLIT_STRING + HadoopConfig.getFileName());
        FileStatus fileStatus = hdfs.getFileStatus(file);
        BlockLocation[] location = hdfs.getFileBlockLocations(fileStatus, 0, fileStatus.getLen());
        for (BlockLocation block : location) {
            String[] hosts = block.getHosts();
            for (String host : hosts) {
                System.out.println("block:" + block + " host:" + host);
            }
        }
    }

    private static void iteratorListFile(FileSystem hdfs, Path path) throws Exception {
        FileStatus[] files = hdfs.listStatus(path);
        for (FileStatus file : files) {
            if (file.isDirectory()) {
                System.out.println(file.getPermission() + " " + file.getOwner()
                        + " " + file.getGroup() + " " + file.getPath());
                iteratorListFile(hdfs, file.getPath());
            } else if (file.isFile()) {
                System.out.println(file.getPermission() + " " + file.getOwner()
                        + " " + file.getGroup() + " " + file.getPath());
            }
        }
    }
}
