package com.ai.ipu.example.kafka;

import com.ai.aif.msgframe.MfProducerClient;
import com.ai.aif.msgframe.common.CompletionListener;
import com.ai.aif.msgframe.common.message.MsgFMessage;
import com.ai.aif.msgframe.common.message.MsgFTextMessage;
import org.apache.log4j.Logger;
import org.junit.Test;

import java.util.Date;


/**
 * @author liutong3
 * @team IPU
 * @date 2019/6/6 16:07
 * @desc kafka生产者
 */
public class KafkaProducerExample {
    private static final Logger LOG = Logger.getLogger(KafkaProducerExample.class);
    private final String TOPIC = "test";
    private final String MESSAGE = "test";
    private final String ORDERID = "1000";

    @Test
    public void testSendMessage() {
        String message = getMessage();
        sendMessage(TOPIC, message);
    }

    @Test
    public void testSendAsyncMessage() {
        String message = getMessage();
        sendAsyncMessage(TOPIC, message);
    }

    @Test
    public void testSendOrderMessage() {
        String message = getMessage();
        sendOrderMessage(TOPIC, message, ORDERID);
    }

    private String getMessage() {
        return MESSAGE + "_" + new Date().getTime();
    }

    /**
     * 普通消息发送
     */
    private void sendMessage(String topic, String text) {
        try {
            MfProducerClient client = new MfProducerClient();
            MsgFTextMessage message = new MsgFTextMessage();
            message.setText(text);
            client.send(topic, message);
            LOG.debug("Sent:" + message);
            Thread.currentThread().sleep(1000);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 异步消息发送
     */
    private void sendAsyncMessage(String topic, final String text) {
        try {
            MfProducerClient client = new MfProducerClient();
            final MsgFTextMessage message = new MsgFTextMessage();
            message.setText(text);
            client.asyncSend(topic, message, new CompletionListener() {
                public void onCompletion(MsgFMessage msgFMessage) {
                    LOG.debug("Sent Success:" + msgFMessage.getMsgId() + "-" + text);
                }

                public void onException(MsgFMessage msgFMessage, Exception e) {
                    LOG.debug("Sent Error:" + msgFMessage.getMsgId() + "-" + text);
                }
            });
            Thread.currentThread().sleep(1000);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 顺序消息发送
     */
    private void sendOrderMessage(String topic, final String text, String orderId) {
        try {
            MfProducerClient client = new MfProducerClient();
            final MsgFTextMessage message = new MsgFTextMessage();
            message.setText(text);
            client.sendOrderMsg(topic, message, orderId);
            LOG.debug("Sent:" + message);
            Thread.currentThread().sleep(1000);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
