package com.ai.ipu.example.zookeeper;


import org.apache.curator.framework.recipes.cache.PathChildrenCacheEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


import com.ai.ipu.zk.listener.AbstractEventWatcher;

/**
 * 节点操作类
 * 对于PushMgmt <--> zookeeper集群而言，是 1 v 1 的连接
 *
 *
 * @author kevin
 *
 */
public class PushServerPathWatcher extends AbstractEventWatcher<PathChildrenCacheEvent>{
    private static final Logger LOG = LoggerFactory.getLogger(PushServerPathWatcher.class);

    /**
     * 节点添加，适用于TreeNodeCache、PathParentCache
     *
     * @param event 触发事件
     */
    @Override
    public void addListener(PathChildrenCacheEvent event) {
        if(event.getData() == null)
            return;
        LOG.debug("PushServerPathWatcher-add:path=["+event.getData().getPath()+"],value=["+new String(event.getData().getData())+"]");
    }

    /**
     * 节点删除，适用于PathParentCache、TreeNodeCache
     *
     * @param event 触发事件
     */
    @Override
    public void removeListener(PathChildrenCacheEvent event) {
        if(event.getData() == null)
            return;
        LOG.debug("PushServerPathWatcher-remove:path=["+event.getData().getPath()+"],value=["+new String(event.getData().getData())+"]");
    }

    /**
     * 节点修改，适用于PathParentCache、TreeNodeCache
     *
     * 只有当 Push-Server 的 http 端口修改时，才会触发相应操作；
     *
     * @param event 触发事件
     */
    @Override
    public void changeListener(PathChildrenCacheEvent event) {
        //空数据不予处理
        if(event.getData() == null)
            return;

        LOG.debug("PushServerPathWatcher-modify:path=["+event.getData().getPath()+"],value=["+new String(event.getData().getData())+"]");
    }
}
