package com.ai.ipu.example.zookeeper;

import com.ai.ipu.zk.listener.AbstractEventWatcher;
import org.apache.curator.framework.recipes.cache.TreeCacheEvent;
import org.apache.zookeeper.data.Stat;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * 节点操作类
 * 对于PushMgmt <--> zookeeper集群而言，是 1 v 1 的连接
 *
 *
 * @author kevin
 *
 */
public class PushServerTreeWatcher extends AbstractEventWatcher<TreeCacheEvent>{
    private static final Logger LOG = LoggerFactory.getLogger(PushServerTreeWatcher.class);

    /**
     * 节点添加，适用于TreeNodeCache、PathParentCache
     *
     * @param event 触发事件
     */
    @Override
    public void addListener(TreeCacheEvent event) {
        //不需要关注的目录跳过
        if(skip(event)) return;
        LOG.debug("PushServerTreeWatcher-add:path=["+event.getData().getPath()+"],value=["+ new String(event.getData().getData())+"]");
    }
    /**
     * 节点删除，适用于PathParentCache、TreeNodeCache
     *
     * @param event 触发事件
     */
    @Override
    public void removeListener(TreeCacheEvent event) {
        //空数据不予处理
        if(event.getData() == null)
            return;

        if (event.getData().getData() == null) {
            LOG.debug("PushServerTreeWatcher-remove:path=["+event.getData().getPath()+"],value=[]");
        } else {
            LOG.debug("PushServerTreeWatcher-remove:path=["+event.getData().getPath()+"],value=["+ new String(event.getData().getData())+"]");
        }
    }

    /**
     * 节点修改，适用于PathParentCache、TreeNodeCache
     *
     * 只有当 Push-Server 的 http 端口修改时，才会触发相应操作；
     *
     * @param event 触发事件
     */
    @Override
    public void changeListener(TreeCacheEvent event) {
        //空数据不予处理
        if(event.getData() == null)
            return;

        LOG.debug("PushServerTreeWatcher-modify:path=["+event.getData().getPath()+"],value=["+ new String(event.getData().getData())+"]");
    }
    /**
     * 不需要要处理的事件
     *
     * @param event
     * @return
     * @throws
     */
    private boolean skip(TreeCacheEvent event) {
        //空数据不予处理
        if(event.getData() == null)
            return true;

        //只处理叶子节点（PushServer的值）
        Stat stat = event.getData().getStat();
        if(stat.getNumChildren() != 0)
            return true;

        return false;
    }
}
