package com.ai.ipu.example.zookeeper;

import com.ai.ipu.zk.ICuratorClient;
import com.ai.ipu.zk.ZkClientFactory;
import com.ai.ipu.zk.util.OperType;
import org.junit.Before;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ZookeeperExample {
    private static final Logger LOG = LoggerFactory.getLogger(ZookeeperExample.class);
    private static final String PATH = "test";
    private static final String PATH2 = "test/test2";
    private static final String TYPE = "/myzktest";
    private static final boolean VERSIONCTL = true;
    private static final boolean PERSISTENT = true;
    private ICuratorClient client;

    @Before
    public void setBefore(){
        try {
            client = (ICuratorClient) ZkClientFactory.getZkClient("push");
            setUserDefine();
            client.addPathCacheListener(OperType.Define, PATH, true, new PushServerPathWatcher());
            client.addTreeCacheListener(OperType.Define, PATH, true, new PushServerTreeWatcher());
        } catch (Exception e) {
            LOG.error(e.getMessage(), e);
        }
    }

    private void setUserDefine() {
        OperType.Define.setType(TYPE);
        OperType.Define.setPersistent(PERSISTENT);
        OperType.Define.setVersionCtrl(VERSIONCTL);
    }

    /**
     * 给根节点赋值
     * @throws Exception
     */
    @Test
    public void testSetValueToRoot() throws Exception{
        LOG.debug(Boolean.toString(client.setValue(OperType.Define, PATH, "myData1")));
    }

    /**
     * 给叶子节点赋值，会触发监听器
     * @throws Exception
     */
    @Test
    public void testSetValueToLeaf() throws Exception{
        LOG.debug(Boolean.toString(client.setValue(OperType.Define, PATH2, "myData1")));
    }

    /**
     * 获取节点的值
     * @throws Exception
     */
    @Test
    public void testGetValue() throws Exception {
        LOG.debug(client.getValue(OperType.Define, PATH2));
    }

    /**
     * 删除节点
     * @throws Exception
     */
    @Test
    public void testDeleteNode() throws Exception {
        LOG.debug(Boolean.toString(client.delete(OperType.Define, PATH2)));
    }
}
